import * as LocalData from './LocalData';
import * as Utils from './Utils';

const MAX_BUFF_SIZE = 1000;

let dataArray = [];
let saved = false;
let initialized = false;


let allStorage = {};

/**
 *
 * @param type
 * @returns EventStorage
 */
export function get(type) {
    if (!allStorage[type]) {
        allStorage[type] = new EventStorage(type, MAX_BUFF_SIZE);
    }

    return allStorage[type];
}

class EventStorage {
    constructor(type, size) {
        this._saved = false;
        this._type = type;
        this._size = size;
        this._dataArray = [];

        const events_str = LocalData.getItem("events-" + this._type);
        if (!Utils.isStringEmpty(events_str)) {
            try {
                this._dataArray = JSON.parse(events_str);
            } catch (e) {
                this._dataArray = [];
            }
        }
    }

    push(data) {
        this._dataArray.push(data);

        if (this._dataArray.length > this._size) {
            this._dataArray.shift();
            console.warn("drop off event");
        }

        this._saved = false;
        this._save();
    }

    shift(num) {
        num = Math.min(num, this._dataArray.length);
        const ret = this._dataArray.splice(0, num);
        this._saved = false;
        this._save();
        return ret;
    }

    getlength() {
        return this._dataArray.length;
    }

    _save() {
        const that = this;
        setTimeout(function () {
            if (that._saved) {
                return;
            }

            LocalData.setItem("events-" + that._type, JSON.stringify(that._dataArray));
            that._saved = true;
        }, 100);
    }
}

function save() {
    setTimeout(function () {
        if (saved) {
            return;
        }
        LocalData.setItem("events", JSON.stringify(dataArray));
        saved = true;
    }, 100);
}

export function push(data) {
    get("").push(data);
}

export function shift(num) {
    return get("").shift(num);
}

export function getSize() {
    return get("").length;
}
